@@ -467,10 +467,11 @@ function install_setup_get_templates() {
 	@ini_set('zlib.output_compression', '0');
 
 	$templates = array(
+		'Apache_Webserver.xml.gz',
 		'Cacti_Stats.xml.gz',
-		'Cisco_ASA_Appliance.xml.gz',
 		'Cisco_Router.xml.gz',
 		'Citrix_NetScaler_VPX.xml.gz',
+		'ESXi_Device.xml.gz',
 		'Generic_SNMP_Device.xml.gz',
 		'Local_Linux_Machine.xml.gz',
 		'NetSNMP_Device.xml.gz',
@@ -707,6 +708,17 @@ function install_file_paths() {
 			'win32' => 'c:/spine/bin/spine.exe'
 		));
 
+	// Workaround to support *BSD systems
+	if ($config['cacti_server_os'] == 'unix') {
+		$paths = array('/usr/local/spine/bin/spine', '/usr/local/bin/spine');
+		foreach($paths as $path) {
+			if (file_exists($path)) {
+				$input['path_spine']['default'] = $path;
+				break;
+			}
+		}
+	}
+
 	$input['path_spine_config'] = $settings['path']['path_spine_config'];
 
 	/* log file path */
@@ -1097,7 +1109,7 @@ function install_full_sync() {
 					db_execute_prepared('UPDATE poller
 						SET last_sync = NOW()
 						WHERE id = ?',
-						array($id));
+						array($poller['id']));
 				} else {
 					log_install_debug('sync', 'Failed replication to Poller ' . $poller['id']);
 					$failed[] = $poller['id'];
